@@ -280,7 +280,7 @@ class MonitorJobSite:
                self.logger.log(logging.ERROR,getLogMessage("Build sshCommand failed for %s" % (self.siteDesignator)))
                self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
 
-         if sshCommand != "":
+         if sshCommand:
             self.logger.log(logging.INFO,getLogMessage("****************************************"))
             self.logger.log(logging.INFO,getLogMessage("* %s job monitor started *" % (self.siteDesignator)))
             self.logger.log(logging.INFO,getLogMessage("****************************************"))
